==> haskell-wai-app-static-3.1.9-222-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-4uOIlQH3zdpA3ZlOly7mj8
key:                  wai-app-static-3.1.9-4uOIlQH3zdpA3ZlOly7mj8
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  4e5a4ac1c5bb48790f1e974a94532a75
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-4uOIlQH3zdpA3ZlOly7mj8
depends:
    base-4.18.2.1 blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj
    blaze-markup-0.8.3.0-HpRZXcaallq6cQxvG0d1r8 bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    directory-1.3.8.5 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filepath-1.4.300.1 http-date-0.0.11-4LxDv0ZfUydJn5ERHERTdC
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj
    wai-extra-3.1.18-1cKRYsHDvT8fkYumb3esL
    warp-3.4.0-HpC7vpiyF2eriPYOziTRJ zlib-0.7.0.0-5otxZx3SVlrUZcbECZKz5

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.9-224-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-5YuV7YlKgoJECZOZIgHDZ
key:                  wai-app-static-3.1.9-5YuV7YlKgoJECZOZIgHDZ
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  aadac90446ec51dad9058a10dbccb0bd
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-5YuV7YlKgoJECZOZIgHDZ
depends:
    base-4.18.2.1 blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx
    blaze-markup-0.8.3.0-JJ5r8tycCxXJkM0kXa0ha9 bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    directory-1.3.8.5 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filepath-1.4.300.1 http-date-0.0.11-9AFt6UkMptmCfRQJmnvzGs
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-extra-3.1.18-1ANzYYqVephHj2C1lo6Zwk
    warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
    zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
